FairsharingAligner
==================

.. currentmodule:: bioregistry.align

.. autoclass:: FairsharingAligner
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~FairsharingAligner.alt_key_match
      ~FairsharingAligner.curation_header
      ~FairsharingAligner.key
      ~FairsharingAligner.skip_deprecated

   .. rubric:: Methods Summary

   .. autosummary::

      ~FairsharingAligner.get_curation_row
      ~FairsharingAligner.getter

   .. rubric:: Attributes Documentation

   .. autoattribute:: alt_key_match
   .. autoattribute:: curation_header
   .. autoattribute:: key
   .. autoattribute:: skip_deprecated

   .. rubric:: Methods Documentation

   .. automethod:: get_curation_row
   .. automethod:: getter
